@@ -37,7 +37,8 @@ impl WithPulse for tract_nnef::framework::Nnef {
 }
 
 pub fn tract_nnef_registry() -> Registry {
-    let mut reg = Registry::new("pulse");
+    let mut reg = Registry::new("tract_pulse");
+    reg.aliases.push("pulse".to_string());
     delay::register(&mut reg);
     reg
 }
